require 'minitest_helper'

module TestProtonet
  module Hardware
    class StorageTest < Minitest::Test
      def test_empty_volumes
        assert_equal empty_storage.disks, []
      end

      def test_storages_with_disks
        n = 10
        storage = storage_with_disks(n)
        assert_equal n, storage.disks.size
        storage.disks.each do |disk|
          assert_instance_of ::Protonet::Hardware::Disk, disk
        end
      end

      def test_usb_storage
        assert usb_storage.usb?
        refute scsi_storage.usb?
      end

      private
        def empty_storage
          ::Protonet::Hardware::Storage.new
        end

        def storage_with_disks(n)
          ::Protonet::Hardware::Storage.new({ "children" => [{}] * n })
        end

        def usb_storage
          ::Protonet::Hardware::Storage.new({ "businfo" => "usb@3.2" })
        end

        def scsi_storage
          ::Protonet::Hardware::Storage.new({ "businfo" => "scsi@3.2" })
        end
    end
  end
end
